@@ -194,9 +194,9 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-        train_acc = self.val_acc(outputs.logits.argmax(1), labels)
+        acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("train_loss", loss, prog_bar=True, logger=True)
-        self.log(f"train_acc", train_acc, prog_bar=True,logger=True)
+        self.log(f"train_acc", acc, prog_bar=True,logger=True)
         return loss
 
     def validation_step(self, batch, batch_size):
@@ -212,9 +212,9 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-        val_acc = self.val_acc(outputs.logits.argmax(1), labels)
+        acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("val_loss", loss, prog_bar=True, logger=True)
-        self.log(f"val_acc", val_acc, prog_bar=True,logger=True)
+        self.log(f"val_acc", acc, prog_bar=True,logger=True)
         return loss
 
     def test_step(self, batch, batch_size):
